##  Introduction to the Meta Model
The meta model in SAP LeanIX is a conceptual model that defines the structure, relationships, and semantics of fact sheets, providing a framework for documenting and managing enterprise architecture. While the meta model is based on best practices for enterprise architecture management, you can customize it to meet your unique needs.
Fact sheets are the main objects within the meta model. They contain information about various elements in your architectural landscape. The predefined meta model includes 12 fact sheet types, each representing a distinct architectural element. You can tailor each fact sheet type by modifying predefined attributes and creating custom ones.
For additional information, see:
  * [Meta Model](https://help.sap.com/docs/leanix/ea/meta-model?locale=en-US&state=PRODUCTION&version=CLOUD "Get an overview of the SAP LeanIX meta model and its key concepts.")
  * [Fact Sheets](https://help.sap.com/docs/leanix/ea/fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD "Fact sheets in SAP LeanIX are used to record essential and comprehensive details about each architectural object, such as applications, business capabilities, IT components, etc. Learn about their structure, types, and subtypes.")


![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275732167a441014b56ed6ccf18304d6_LowRes.png)
Meta Model
